[ARVADOS] updated: f831106444b3591b96fc204460092f85bbf7495d

git at public.curoverse.com git at public.curoverse.com
Mon Feb 15 13:22:49 EST 2016


Summary of changes:
 tools/crunchstat-summary/crunchstat_summary/summarizer.py | 15 ++++++++-------
 1 file changed, 8 insertions(+), 7 deletions(-)

       via  f831106444b3591b96fc204460092f85bbf7495d (commit)
      from  3920b0d627ac89687a741b186554c1afd61750f5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit f831106444b3591b96fc204460092f85bbf7495d
Author: Tom Clegg <tom at curoverse.com>
Date:   Mon Feb 15 13:22:03 2016 -0500

    8409: Use 80% utilization as keep_cache_mb_per_task reporting threshold. refs #8409

diff --git a/tools/crunchstat-summary/crunchstat_summary/summarizer.py b/tools/crunchstat-summary/crunchstat_summary/summarizer.py
index d058c23..f422501 100644
--- a/tools/crunchstat-summary/crunchstat_summary/summarizer.py
+++ b/tools/crunchstat-summary/crunchstat_summary/summarizer.py
@@ -336,19 +336,20 @@ class Summarizer(object):
                 int(math.ceil(nearlygibs(used_mib))*AVAILABLE_RAM_RATIO*1024))
 
     def _recommend_keep_cache(self):
-        """Recommend increasing keep cache if miss rate is above 0.2%"""
-        if self.job_tot['keepcalls']['get'] == 0:
+        """Recommend increasing keep cache if utilization < 80%"""
+        if self.job_tot['net:keep0']['rx'] == 0:
             return
-        miss_rate = float(self.job_tot['keepcache']['miss']) / float(self.job_tot['keepcalls']['get']) * 100.0
+        utilization = (float(self.job_tot['blkio:0:0']['read']) /
+                       float(self.job_tot['net:keep0']['rx']))
         asked_mib = self.existing_constraints.get('keep_cache_mb_per_task', 256)
 
-        if miss_rate > 0.2:
+        if utilization < 0.8:
             yield (
-                '#!! {} Keep cache miss rate was {:.2f}% -- '
-                'try runtime_constraints "keep_cache_mb_per_task":{}'
+                '#!! {} Keep cache utilization was {:.2f}% -- '
+                'try runtime_constraints "keep_cache_mb_per_task":{} (or more)'
             ).format(
                 self.label,
-                miss_rate,
+                utilization * 100.0,
                 asked_mib*2)
 
 

-----------------------------------------------------------------------


hooks/post-receive
-- 




More information about the arvados-commits mailing list